#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-HvOtK44oL8xHdEteEJPDR0
key:                  dhall-1.42.3-HvOtK44oL8xHdEteEJPDR0
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  e6929462df49bd2062bedfe1b1726a55
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-HvOtK44oL8xHdEteEJPDR0
depends:
    Diff-0.5-Lpdp6cGB4OPHlY6nud0H07
    aeson-2.2.2.0-HX3VmpxSu7MBeXlY03a2B0
    aeson-pretty-0.8.10-EYHzIte6KbSLrMzV6qr2Uj
    ansi-terminal-1.1-JoJLZTsqfbj9DJv1N5mqCP
    atomic-write-0.2.1.1-61u1heuFI239aedkfgIG15 base-4.18.2.1
    base16-bytestring-1.0.2.0-AGwhh1Ev3mPCOOC4X0N9yh
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-2eph4zYoAFzHEvr0xd94hH
    cborg-0.2.10.0-73FJisgfs8l79lkrrgnKbd
    cborg-json-0.2.6.0-BMKwwyi14G827e3DSNHyct containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-Lew3cwp9YBsLfDsPCQuWBu
    data-fix-0.3.4-DmdJAIk9llpEKNjqvetNz7 deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-4tr4rvsXIekxhVIxYYnuv exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-FwNAiEK503L2zH02nnI1E9
    hashable-1.4.7.0-J2hh6EbI83E8iCoykKa5KL haskeline-0.8.2.1
    http-client-0.7.19-7W2xEySZC72756AXFfqUV4
    http-client-tls-0.3.6.4-PDqn3Ot8iJH3sGWMePnKH
    http-types-0.12.4-1JnQTH18RU0DibFo35M5JY
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-7cd47IbTYxOImQ5PCJywvW
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-EPISvuAciHNCNyhUbkgF33
    optparse-applicative-0.18.1.0-2Hiadv6BpzgDgx5QxnTvo5
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-HZLaRuSBcxoHpXfm3luxLt
    pretty-simple-4.1.4.0-ACllDObXdn44C2BPh3OrOO
    prettyprinter-1.7.1-1xxpbQWBfCkKy2RpQWmuRC
    prettyprinter-ansi-terminal-1.1.4-GGItlmiu8UCFEJf6nVTmBY
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-652cwqsM8CP9x29NG2IMof
    serialise-0.2.6.1-2AYZZsdYi2IHU1gOYkK7Vo template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-GmjNzLLv5a34NIDYlpsBNo
    text-short-0.1.6.1-3kIbOzqw7fzGjL4mZZhstA
    th-lift-instances-0.1.20-IJXLRbuBGD97g1L7kc2ykY time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-G3cHmsN0OSSCkVhMEU4yM8
    unordered-containers-0.2.20.1-F8uKhGV3AlWbjcYkQjkcw
    vector-0.13.2.0-DMZHGTdGAnaIWH7Z4Bo5hL

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

